@@ -31,7 +31,7 @@ class Launch:
     # 1c
     @staticmethod
     def close_temporary_files_modal():
-        position = Ui_tools.getPosition(resource_path('\static\1b.png'))
+        position = Ui_tools.getPosition(resource_path('\static\\1b.png'))
 
         if position is not None:
             Ui_tools.hot_key('Esc')
